@@ -79,7 +79,7 @@ cl_z80::init(void)
   return(0);
 }
 
-char *
+const char *
 cl_z80::id_string(void)
 {
   return("unspecified Z80");
@@ -159,9 +159,8 @@ int
 cl_z80::inst_length(t_addr addr)
 {
   int len = 0;
-  char *s;
 
-  s = get_disasm_info(addr, &len, NULL, NULL);
+  get_disasm_info(addr, &len, NULL, NULL);
 
   return len;
 }
@@ -170,9 +169,8 @@ int
 cl_z80::inst_branch(t_addr addr)
 {
   int b;
-  char *s;
 
-  s = get_disasm_info(addr, NULL, &b, NULL);
+  get_disasm_info(addr, NULL, &b, NULL);
 
   return b;
 }
@@ -184,13 +182,13 @@ cl_z80::longest_inst(void)
 }
 
 
-char *
+const char *
 cl_z80::get_disasm_info(t_addr addr,
                         int *ret_len,
                         int *ret_branch,
                         int *immed_offset)
 {
-  char *b = NULL;
+  const char *b = NULL;
   uint code;
   int len = 0;
   int immed_n = 0;
@@ -310,11 +308,12 @@ cl_z80::get_disasm_info(t_addr addr,
   return b;
 }
 
-char *
+const char *
 cl_z80::disass(t_addr addr, char *sep)
 {
   char work[256], temp[20];
-  char *buf, *p, *b, *t;
+  const char *b;
+  char *buf, *p, *t;
   int len = 0;
   int immed_offset = 0;
 
@@ -373,10 +372,10 @@ cl_z80::disass(t_addr addr, char *sep)
     buf= (char *)malloc(6+strlen(p)+1);
   else
     buf= (char *)malloc((p-work)+strlen(sep)+strlen(p)+1);
-  for (p= work, b= buf; *p != ' '; p++, b++)
-    *b= *p;
+  for (p= work, t= buf; *p != ' '; p++, t++)
+    *t= *p;
   p++;
-  *b= '\0';
+  *t= '\0';
   if (sep == NULL)
     {
       while (strlen(buf) < 6)
